@@ -10,7 +10,7 @@ from mezzanine.settings import PAGES_MENU_SHOW_ALL
 register = template.Library()
 
 
-def _page_menu(context, parent_page, page_qs):
+def _page_menu(context, parent_page):
     """
     Return a list of child pages for the given parent, storing all 
     pages in a dict in the context when first called using parents as keys 
@@ -18,8 +18,15 @@ def _page_menu(context, parent_page, page_qs):
     """
     if "menu_pages" not in context:
         pages = defaultdict(list)
-        for page in page_qs.order_by("ordering"):
-            slug = context["request"].path.strip("/")
+        try:
+            user = context["request"].user
+        except KeyError:
+            user = None
+        for page in Page.objects.published(for_user=user).order_by("ordering"):
+            try:
+                slug = context["request"].path.strip("/")
+            except KeyError:
+                slug = ""
             setattr(page, "selected", slug.startswith(page.slug))
             pages[page.parent_id].append(page)
         context["menu_pages"] = pages
@@ -34,14 +41,12 @@ def page_menu(context, parent_page=None):
     """
     Public page menu.
     """
-    return _page_menu(context, parent_page, 
-        Page.objects.published(for_user=context["request"].user))
+    return _page_menu(context, parent_page)
 
 @register.inclusion_tag("admin/includes/page_menu.html", takes_context=True)
 def page_menu_admin(context, parent_page=None):
     """
     Admin page menu.
     """
-    return _page_menu(context, parent_page, 
-        Page.objects.published(for_user=context["request"].user))
+    return _page_menu(context, parent_page)
 
